#include <zephyr/bluetooth/bluetooth.h>
#include <zephyr/bluetooth/hci.h>
#include <host/hci_core.h>
#include <zephyr/bluetooth/conn.h>
#include <zephyr/bluetooth/uuid.h>
#include <zephyr/bluetooth/gatt.h>
#include <bluetooth/gatt_dm.h>
#include <bluetooth/services/dfu_smp.h>

#include <zephyr/bluetooth/controller.h>
#include <zephyr/bluetooth/hci_vs.h>
#include <bluetooth/scan.h>
#include <zephyr/sys/byteorder.h>
#include <zephyr/logging/log.h>

#include "peer_utils.h"

#define LOG_MODULE_NAME peer_utils
LOG_MODULE_REGISTER(LOG_MODULE_NAME);

static bool online = false;
static struct bt_conn* client_conn = NULL;
static bt_addr_le_t client_addr;
static struct bt_dfu_smp clientdfu_smp;
static struct k_sem send_to_ota_sem;
int8_t rssi;

void put_addr_in_peer(uint8_t* addr)
{
    memcpy(&client_addr.a, addr, BT_ADDR_SIZE);
    client_addr.type = BT_ADDR_LE_RANDOM;

    memset(&clientdfu_smp, 0, sizeof(clientdfu_smp));
    k_sem_init(&send_to_ota_sem, 1, 1);
}

void set_client_conn(struct bt_conn* conn)
{
    client_conn = conn;
}

struct bt_conn* get_client_conn(void)
{
    return client_conn;
}

struct bt_dfu_smp* get_peer_dfu_smp(int p_idx)
{
    return &clientdfu_smp;
}

bt_addr_le_t* peer_get_le_addr(int idx)
{
    return &client_addr;
}

struct k_sem* get_peer_send_to_ota_sem(int p_idx)
{
    return &send_to_ota_sem;
}

void set_peer_online(int p_idx)
{
    online = true;
}

void set_peer_offline(int p_idx)
{
    online = false;

}

bool get_peer_online(int p_idx)
{
    return online;
}

int get_peers_idx_from_bt_addr_le_t(const bt_addr_le_t* addr)
{
    if (bt_addr_le_cmp(&client_addr, addr) == 0) {
            return 0;
    }
    
    return -1;
}

void set_peer_rssi(int8_t in_rssi)
{
    rssi = in_rssi;
}

int8_t get_peer_rssi(void)
{
    return rssi;
}