#ifndef PEER_UTILS_H_
#define PEER_UTILS_H_

#include <zephyr/kernel.h>
#include <bluetooth/gatt_dm.h>
#include <bluetooth/services/dfu_smp.h>

#define IP_TEMP_IDX                                                            0
#define FP_TEMP_IDX                                                            1
#define IP_HUMI_IDX                                                            2
#define FP_HUMI_IDX                                                            3
#define BTN_UP_IDX                                                             4
#define BTN_DOWN_IDX                                                           5
#define BATT_LEVEL_IDX                                                         6
#define IP_TARGET_IDX                                                          7
#define FP_TARGET_IDX                                                          8
#define SW_MAJOR_IDX                                                           9
#define SW_MINOR_IDX                                                          10
#define SW_PATCH_IDX                                                          11

#define BLE_MSGQ_BUF_SIZE                                                     64
#define BLE_MSGQ_SIZE                                                         10
#define BLE_MSGQ_ALIGNMENT                                                     4
#define BLE_MSGQ_TYPE_IDX                                                      7
#define BLE_MSGQ_TEMP_IP_IDX                                                   8
#define BLE_MSGQ_TEMP_FP_IDX                                                   9
#define BLE_MSGQ_ERROR_LIST_IDX                                                8
#define FW_HASH_LEN                                                         0x20

#define MAX_DEVICE_ERRORS                                                      2
#define MAX_NBR_GLOBAL_ERRORS                                                  5

#define ABS(x) ((x < 0) ? -(x) : (x))

typedef struct {
    int p_idx;
    uint16_t adv_int;
    int8_t rssi;
    uint8_t connected;
    uint8_t adv_num;
    size_t errorlist_len;
    uint8_t errorlist[MAX_DEVICE_ERRORS * sizeof(uint32_t)];
    uint8_t sensor_data[12];
} adv_le_user_data_t;

void put_addr_in_peer(uint8_t* addr);
void set_client_conn(struct bt_conn* conn);
struct bt_conn* get_client_conn(void);

void set_peer_online(int p_idx);
void set_peer_offline(int p_idx);
bool get_peer_online(int p_idx);

struct bt_dfu_smp* get_peer_dfu_smp(int p_idx);
bt_addr_le_t* peer_get_le_addr(int idx);
struct k_sem* get_peer_send_to_ota_sem(int p_idx);
int get_peers_idx_from_bt_addr_le_t(const bt_addr_le_t* addr);

void set_peer_rssi(int8_t in_rssi);
int8_t get_peer_rssi(void);

#endif /* PEER_UTILS_H_ */
